<?php
/**
 * Whether the current request is in post type pages
 *
 * @param mixed $post_types
 *
 * @return bool True if inside post type pages
 */
function wonderloops_is_post_type( $post_types = '' ) {
	if ( wonderloops_is_post_type_list( $post_types ) || wonderloops_is_post_type_new( $post_types ) || wonderloops_is_post_type_edit( $post_types ) || wonderloops_is_post_type_post( $post_types ) || wonderloops_is_post_type_taxonomy( $post_types ) ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Whether the current request is in post type list page
 *
 * @param mixed $post_types
 *
 * @return bool True if inside post type list page
 */
function wonderloops_is_post_type_list( $post_types = '' ) {
	if ( 'edit.php' != basename( $_SERVER['PHP_SELF'] ) ) {
		return false;
	}
	if ( $post_types == '' ) {
		return true;
	} else {
		$check = isset( $_GET['post_type'] ) ? $_GET['post_type'] : ( isset( $_POST['post_type'] ) ? $_POST['post_type'] : 'post' );
		if ( is_string( $post_types ) && $check == $post_types ) {
			return true;
		} elseif ( is_array( $post_types ) && in_array( $check, $post_types ) ) {
			return true;
		}

		return false;
	}
}

/**
 * Whether the current request is in post type new page
 *
 * @param mixed $post_types
 *
 * @return bool True if inside post type new page
 */
function wonderloops_is_post_type_new( $post_types = '' ) {
	if ( 'post-new.php' != basename( $_SERVER['PHP_SELF'] ) ) {
		return false;
	}
	if ( $post_types == '' ) {
		return true;
	} else {
		$check = isset( $_GET['post_type'] ) ? $_GET['post_type'] : ( isset( $_POST['post_type'] ) ? $_POST['post_type'] : 'post' );
		if ( is_string( $post_types ) && $check == $post_types ) {
			return true;
		} elseif ( is_array( $post_types ) && in_array( $check, $post_types ) ) {
			return true;
		}

		return false;
	}
}

/**
 * Whether the current request is in post type post page
 *
 * @param mixed $post_types
 *
 * @return bool True if inside post type post page
 */
function wonderloops_is_post_type_post( $post_types = '' ) {
	if ( 'post.php' != basename( $_SERVER['PHP_SELF'] ) ) {
		return false;
	}
	if ( $post_types == '' ) {
		return true;
	} else {
		$post  = isset( $_GET['post'] ) ? $_GET['post'] : ( isset( $_POST['post'] ) ? $_POST['post'] : false );
		$check = get_post_type( $post );

		if ( is_string( $post_types ) && $check == $post_types ) {
			return true;
		} elseif ( is_array( $post_types ) && in_array( $check, $post_types ) ) {
			return true;
		}

		return false;
	}
}

/**
 * Whether the current request is in post type edit page
 *
 * @param mixed $post_types
 *
 * @return bool True if inside post type edit page
 */
function wonderloops_is_post_type_edit( $post_types = '' ) {
	if ( 'post.php' != basename( $_SERVER['PHP_SELF'] ) ) {
		return false;
	}
	$action = isset( $_GET['action'] ) ? $_GET['action'] : ( isset( $_POST['action'] ) ? $_POST['action'] : '' );
	if ( 'edit' != $action ) {
		return false;
	}

	if ( $post_types == '' ) {
		return true;
	} else {
		$post  = isset( $_GET['post'] ) ? $_GET['post'] : ( isset( $_POST['post'] ) ? $_POST['post'] : false );
		$check = get_post_type( $post );

		if ( is_string( $post_types ) && $check == $post_types ) {
			return true;
		} elseif ( is_array( $post_types ) && in_array( $check, $post_types ) ) {
			return true;
		}

		return false;
	}
}

/**
 * Whether the current request is in post type taxonomy pages
 *
 * @param mixed $post_types
 *
 * @return bool True if inside post type taxonomy pages
 */
function wonderloops_is_post_type_taxonomy( $post_types = '' ) {
	if ( 'edit-tags.php' != basename( $_SERVER['PHP_SELF'] ) ) {
		return false;
	}
	if ( $post_types == '' ) {
		return true;
	} else {
		$check = isset( $_GET['post_type'] ) ? $_GET['post_type'] : ( isset( $_POST['post_type'] ) ? $_POST['post_type'] : 'post' );
		if ( is_string( $post_types ) && $check == $post_types ) {
			return true;
		} elseif ( is_array( $post_types ) && in_array( $check, $post_types ) ) {
			return true;
		}

		return false;
	}
}

function wfl_ReadMore() {
	return array(
		'type'        => 'checkbox',
		'heading'     => __( 'Show Read More?', 'wonder_loops' ),
		'param_name'  => 'read_more',
		'description' => __( 'If selected, Read More will be shown.', 'wonder_loops' ),
		'value'       => array( __( 'Yes, please', 'wonder_loops' ) => 'yes' )
	);
}

function wfl_link_to_post() {
	return array(
		'type'        => 'checkbox',
		'heading'     => __( 'Link to post?', 'wonder_loops' ),
		'param_name'  => 'link_to_post',
		'description' => __( 'If selected, Item will link to post.', 'wonder_loops' ),
		'value'       => array( __( 'Yes, please', 'wonder_loops' ) => 'yes' )
	);
}

function wfl_select_tags( $name, $title, $default, $values, $dependent = false ) {
	$tags = array(
		'type'       => 'dropdown',
		'heading'    => $title,
		'param_name' => $name,
		'value'      => $values,
		'std'        => $default,
	);
	if ( $dependent ) {
		$tags['dependency'] = $dependent;
	}

	return $tags;
}

function wfl_select_template( $name, $title, $default ) {
	$wldi       = WONDERLOOPS_TEMPLATES;
	$loop_files = array();
	$wldir      = @opendir( $wldi );
	if ( $wldir ) {
		while ( ( $file = readdir( $wldir ) ) !== false ) {
			if ( substr( $file, 0, 1 ) == '.' ) {
				continue;
			}
			if ( substr( $file, - 4 ) == '.php' ) {
				$loop_files[] = $file;
			}
		}
	}
	@closedir( $wldir );
	$wldi  = get_stylesheet_directory() . '/wonderloops';
	$wldir = @opendir( $wldi );
	if ( $wldir ) {
		while ( ( $file = readdir( $wldir ) ) !== false ) {
			if ( substr( $file, 0, 1 ) == '.' ) {
				continue;
			}
			if ( substr( $file, - 4 ) == '.php' ) {
				$loop_files[] = $file;
			}
		}
	}
	@closedir( $wldir );
	$values = array_unique( $loop_files );
	$tags   = array(
		'type'       => 'dropdown',
		'heading'    => $title,
		'param_name' => $name,
		'value'      => $values,
		'std'        => $default,
	);

	return $tags;
}

function wfl_tag_open( $wrapper, $wrapperclass = false ) {
	$wrapopen = '';
	if ( strlen( $wrapper ) && $wrapper != 'none' ) {
		$wrapopen = '<' . $wrapper;
		if ( $wrapperclass && strlen( $wrapperclass ) ) {
			$wrapopen .= ' class="' . $wrapperclass . '"';
		}
		$wrapopen .= '>' . "\n";
	}

	return $wrapopen;
}

function wfl_tag_close( $wrapper ) {
	$wrapclose = '';
	if ( strlen( $wrapper ) && $wrapper != 'none' ) {
		$wrapclose = '</' . $wrapper . '>' . "\n";
	}

	return $wrapclose;
}

function wfl_parent( $parent = false ) {
	if ( $parent ) {
		$ret = array( 'as_child' => array( 'only' => $parent . ', vc_column_inner' ) );
	} else {
		$ret = '';
	}

	return $ret;
}

function wfl_pre_text( $pre_text, $pre_text_tag ) {
	$pretext = '';
	if ( strlen( $pre_text ) != 0 ) {
		if ( $pre_text_tag != 'none' ) {
			$pretext .= '<' . $pre_text_tag . ' class="' . $wrapperclass . '">' . "\n";
		}
	}
	$pretext .= $pre_text;
	if ( $pre_text_tag != 'none' ) {
		$pretext .= '</' . $pre_text_tag . '>' . "\n";
	}

	return $pretext;
}

function wf_hidden_settings_field( $settings, $value ) {
	$value = htmlspecialchars( $value );

	return '<input name="' . $settings['param_name'] . '" class="wpb_vc_param_value vc_hidden-field vc_param-name-' . $settings['param_name'] . ' hidden ' . $settings['type'] . '" type="hidden" value="' . $settings['realvalue'] . '"/>';
}