<?php
/*
 * Plugin Name: Wonder Loops
 * Plugin URI: http://www.wonderfoundry.com
 * Description: Drag and drop loop builder for WordPress using the power of ACF.
 * Version: 2.1.10
 * Author: Ultimatum Theme
 * Author URI: https://ultimatumtheme.com
 * ULT ID: 19
 */

$current_default = get_option( 'stylesheet' );
$theme           = wp_get_theme( $current_default );
if ( strtolower( $theme->get( 'Template' ) ) == 'ultimatum' || strtolower( $theme->get( 'Name' ) ) == 'ultimatum' ) {


	$upload_directory = wp_upload_dir();
	$upload_dir       = $upload_directory["basedir"];
	$upload_url       = $upload_directory["baseurl"];
	define( 'WONDERLOOPS_CACHE_DIR', $upload_dir . '/wonderloops' );
	if ( ! is_dir( WONDERLOOPS_CACHE_DIR ) ) {
		mkdir( WONDERLOOPS_CACHE_DIR );
	}


	define( 'WONDERLOOPS', plugin_dir_path( __FILE__ ) );
	define( 'WONDERLOOPS_INCLUDES', WONDERLOOPS . 'includes' );
	define( 'WONDERLOOPS_TEMPLATES', WONDERLOOPS . 'templates' );
	define( 'WONDERLOOPS_SHORTCODES', WONDERLOOPS . 'shortcodes' );
	define( 'WONDERLOOPS_URL', plugin_dir_url( __FILE__ ) );
	define( 'WONDERLOOPS_IMAGES', WONDERLOOPS_URL . 'assets/images/' );
	define( 'WONDERLOOPS_CSS', WONDERLOOPS_URL . 'assets/css/' );
	define( 'WONDERLOOPS_JS', WONDERLOOPS_URL . 'assets/js/' );


// Get the very Customized ACF plugin
	// require_once( 'advanced-custom-fields-pro/acf.php' );
	if ( get_option( 'wonder_loops_version' ) < 2 ) {
		//require_once( 'advanced-custom-fields/admin/updates/5.0.0.php' );
		// update_option('wonder_loops_version',2);
	}


// Get the classes
	require_once( 'includes/helpers.php' );
	require_once( 'includes/wonderloops.admin.php' );

	//require_once( 'includes/wonderloops.front.php' );


	class WonderLoops {

		function __construct() {
			$this->addPostType();
			add_action( 'vc_before_init', array( $this, 'integrateWithVC' ) );
			if ( is_admin() ) {
				// Get the helper functions

				add_action( 'admin_init', array( $this, 'hide_editor' ) );
				new WonderLoopsAdmin();
			}

		}

		/**
		 * Hide the editor before the post type for loop is selected.
		 */
		function hide_editor() {
			if ( wonderloops_is_post_type( 'wonderloops' ) ) {
				if ( isset( $_GET['post'] ) || isset( $_POST['post_ID'] ) ) {
					$post_id = $_GET['post'] ? $_GET['post'] : $_POST['post_ID'];
					$cura    = get_post_meta( $post_id, 'wonderloops-ptype', true );
					if ( strlen( $cura ) == 0 ) {
						remove_post_type_support( 'wonderloops', 'editor' );
					}
				} else {
					remove_post_type_support( 'wonderloops', 'editor' );
				}
			}

		}

		function addPostType() {
			$labels = array(
				'name'               => __( 'Loops', 'wonderloops' ),
				'singular_name'      => __( 'Loops', 'wonderloops' ),
				'add_new'            => __( 'Add New', 'wonderloops' ),
				'add_new_item'       => __( 'Add New Loop', 'wonderloops' ),
				'edit_item'          => __( 'Edit Loop', 'wonderloops' ),
				'new_item'           => __( 'New Loop', 'wonderloops' ),
				'view_item'          => __( 'View Loop', 'wonderloops' ),
				'search_items'       => __( 'Search Loops', 'wonderloops' ),
				'not_found'          => __( 'No Loops found', 'wonderloops' ),
				'not_found_in_trash' => __( 'No Loops found in Trash', 'wonderloops' ),
			);

			register_post_type( 'wonderloops', array(
				'labels'          => $labels,
				'public'          => false,
				'show_ui'         => true,
				'_builtin'        => false,
				'capability_type' => 'post',
				'hierarchical'    => true,
				'rewrite'         => false,
				'query_var'       => "wonderloops",
				'supports'        => array(
					'title',
					'editor'
				),
				'show_in_menu'    => true,
			) );
		}

		public function integrateWithVC() {
			vc_add_shortcode_param( 'wl2hidden', 'wf_hidden_settings_field' );
			require_once( 'includes/map.php' );
		}

	}

	if ( defined( 'WPB_VC_VERSION' ) ) {
		add_action( 'init', 'init_wonderloops', 8 );
	} else {
		add_action( 'admin_notices', 'wfl_admin_notice_for_vc_activation' );
	}
}
function wfl_admin_notice_for_vc_activation() {
	echo '<div class="updated"><p>The <strong>Wonder Loops</strong> plugin requires <strong>Visual Composer</strong> Plugin installed and activated.</p></div>';
}

function wfl_admin_notice_for_intense_users() {
	echo '<div class="updated"><p>Old version of <strong>Intense</strong> detected! Please update the Intense Plugin to latest version to use <strong>Wonder Loops 2</strong></p></div>';
}

function init_wonderloops() {
	new WonderLoops();
}
